# Dynampy
Stands for **"dynamically organized Python program"**. In other words, specify what is *about to be computed*, store them as **callbacks**, and organize such callbacks in an efficient manner that does not require low-level modification of your code.

# Functionality

- auto-detection of parallelizable computation
- auto-handled parallelization

# pytest
Tests should be put in the `tests` directory.

To run tests, go to the repo's home directory and run `python -m pytest`
